@@ -1,10 +1,10 @@
 """Kedro Telemetry plugin for collecting Kedro usage data."""
 
+import getpass
 import hashlib
 import json
 import logging
 import os
-import socket
 import sys
 from copy import deepcopy
 from datetime import datetime
@@ -16,13 +16,16 @@ import requests
 import yaml
 from kedro.framework.cli.cli import KedroCLI
 from kedro.framework.cli.hooks import cli_hook_impl
-from kedro.framework.startup import ProjectMetadata
+from kedro.framework.hooks import hook_impl
+from kedro.framework.project import pipelines
+from kedro.framework.startup import ProjectMetadata, _get_project_metadata
+from kedro.io.data_catalog import DataCatalog
+from kedro.pipeline import Pipeline
 
-from kedro_telemetry import __version__ as telemetry_version
+from kedro_telemetry import __version__ as TELEMETRY_VERSION
 from kedro_telemetry.masking import _get_cli_structure, _mask_kedro_cli
 
 HEAP_APPID_PROD = "2388822444"
-
 HEAP_ENDPOINT = "https://heapanalytics.com/api/track"
 HEAP_HEADERS = {"Content-Type": "application/json"}
 TIMESTAMP_FORMAT = "%Y-%m-%dT%H:%M:%S.%fZ"
@@ -30,6 +33,23 @@ TIMESTAMP_FORMAT = "%Y-%m-%dT%H:%M:%S.%fZ"
 logger = logging.getLogger(__name__)
 
 
+def _hash(string: str) -> str:
+    return hashlib.sha512(bytes(string, encoding="utf8")).hexdigest()
+
+
+def _get_hashed_username():
+
+    try:
+        username = getpass.getuser()
+        return _hash(username)
+    except Exception as exc:  # pylint: disable=broad-except
+        logger.warning(
+            "Something went wrong with getting the username. Exception: %s",
+            exc,
+        )
+        return ""
+
+
 class KedroTelemetryCLIHooks:
     """Hook to send CLI command data to Heap"""
 
@@ -40,7 +60,6 @@ class KedroTelemetryCLIHooks:
         self, project_metadata: ProjectMetadata, command_args: List[str]
     ):
         """Hook implementation to send command run data to Heap"""
-        # pylint: disable=no-self-use
         try:
             # get KedroCLI and its structure from actual project root
             cli = KedroCLI(project_path=Path.cwd())
@@ -62,32 +81,26 @@ class KedroTelemetryCLIHooks:
 
             logger.debug("You have opted into product usage analytics.")
 
-            try:
-                hashed_computer_name = hashlib.sha512(
-                    bytes(socket.gethostname(), encoding="utf8")
-                )
-            except socket.timeout as exc:
-                logger.warning(
-                    "Socket timeout when trying to get the computer name. "
-                    "No data was sent to Heap. Exception: %s",
-                    exc,
-                )
-                return
-
-            properties = _format_user_cli_data(masked_command_args, project_metadata)
+            hashed_username = _get_hashed_username()
+            project_properties = _get_project_properties(
+                hashed_username, project_metadata
+            )
+            cli_properties = _format_user_cli_data(
+                project_properties, masked_command_args
+            )
 
             _send_heap_event(
                 event_name=f"Command run: {main_command}",
-                identity=hashed_computer_name.hexdigest(),
-                properties=properties,
+                identity=hashed_username,
+                properties=cli_properties,
             )
 
-            # send generic event too so it's easier in data processing
-            generic_properties = deepcopy(properties)
+            # send generic event too, so it's easier in data processing
+            generic_properties = deepcopy(cli_properties)
             generic_properties["main_command"] = main_command
             _send_heap_event(
                 event_name="CLI command",
-                identity=hashed_computer_name.hexdigest(),
+                identity=hashed_username,
                 properties=generic_properties,
             )
         except Exception as exc:  # pylint: disable=broad-except
@@ -98,38 +111,80 @@ class KedroTelemetryCLIHooks:
             )
 
 
-def _format_user_cli_data(command_args: List[str], project_metadata: ProjectMetadata):
-    """Hash username, format CLI command, system and project data to send to Heap."""
-    hashed_username = ""
-    try:
-        hashed_username = hashlib.sha512(bytes(os.getlogin(), encoding="utf8"))
-    except Exception as exc:  # pylint: disable=broad-except
-        logger.warning(
-            "Something went wrong with getting the username to send to Heap. "
-            "Exception: %s",
-            exc,
+class KedroTelemetryProjectHooks:  # pylint: disable=too-few-public-methods
+    """Hook to send project statistics data to Heap"""
+
+    @hook_impl
+    def after_context_created(self, context):
+        """Hook implementation to send project statistics data to Heap"""
+
+        catalog = context.catalog
+        default_pipeline = pipelines.get("__default__")  # __default__
+        hashed_username = _get_hashed_username()
+
+        project_metadata = _get_project_metadata(context.project_path)
+        project_properties = _get_project_properties(hashed_username, project_metadata)
+
+        project_statistics_properties = _format_project_statistics_data(
+            project_properties, catalog, default_pipeline, pipelines
         )
 
-    hashed_package_name = hashlib.sha512(
-        bytes(project_metadata.package_name, encoding="utf8")
-    )
-    hashed_project_name = hashlib.sha512(
-        bytes(project_metadata.project_name, encoding="utf8")
-    )
+        _send_heap_event(
+            event_name="Kedro Project Statistics",
+            identity=hashed_username,
+            properties=project_statistics_properties,
+        )
+
+
+def _get_project_properties(
+    hashed_username: str, project_metadata: ProjectMetadata
+) -> Dict:
+
+    hashed_package_name = _hash(project_metadata.package_name)
+    hashed_project_name = _hash(project_metadata.project_name)
     project_version = project_metadata.project_version
 
     return {
-        "username": hashed_username.hexdigest() if hashed_username else "anonymous",
-        "command": f"kedro {' '.join(command_args)}" if command_args else "kedro",
-        "package_name": hashed_package_name.hexdigest(),
-        "project_name": hashed_project_name.hexdigest(),
+        "username": hashed_username,
+        "package_name": hashed_package_name,
+        "project_name": hashed_project_name,
         "project_version": project_version,
-        "telemetry_version": telemetry_version,
+        "telemetry_version": TELEMETRY_VERSION,
         "python_version": sys.version,
         "os": sys.platform,
     }
 
 
+def _format_user_cli_data(
+    properties: dict,
+    command_args: List[str],
+):
+    """Add format CLI command data to send to Heap."""
+    cli_properties = properties.copy()
+    cli_properties["command"] = (
+        f"kedro {' '.join(command_args)}" if command_args else "kedro"
+    )
+    return cli_properties
+
+
+def _format_project_statistics_data(
+    properties: dict,
+    catalog: DataCatalog,
+    default_pipeline: Pipeline,
+    project_pipelines: dict,
+):
+    """Add project statistics to send to Heap."""
+    project_statistics_properties = properties.copy()
+    project_statistics_properties["number_of_datasets"] = len(
+        catalog.datasets.__dict__.keys()
+    )
+    project_statistics_properties["number_of_nodes"] = (
+        len(default_pipeline.nodes) if default_pipeline else None
+    )
+    project_statistics_properties["number_of_pipelines"] = len(project_pipelines.keys())
+    return project_statistics_properties
+
+
 def _get_heap_app_id() -> str:
     """
     Get the Heap App ID to send the data to.
@@ -144,15 +199,16 @@ def _send_heap_event(
 ) -> None:
     data = {
         "app_id": _get_heap_app_id(),
-        "identity": identity,
         "event": event_name,
         "timestamp": datetime.now().strftime(TIMESTAMP_FORMAT),
         "properties": properties or {},
     }
+    if identity:
+        data["identity"] = identity
 
     try:
         resp = requests.post(
-            url=HEAP_ENDPOINT, headers=HEAP_HEADERS, data=json.dumps(data)
+            url=HEAP_ENDPOINT, headers=HEAP_HEADERS, data=json.dumps(data), timeout=10
         )
         if resp.status_code != 200:
             logger.warning(
@@ -215,3 +271,4 @@ def _confirm_consent(telemetry_file_path: Path) -> bool:
 
 
 cli_hooks = KedroTelemetryCLIHooks()
+project_hooks = KedroTelemetryProjectHooks()
